any_migration

Macro any_migration 

macro_rules! any_migration {
    ($op:ty, $app_name:expr, $migration_name:expr, $parents:expr, $operations:expr) => { ... };
}
Available on crate feature any and (crate features mysql or postgres or sqlite) only.
Macro for implementing the migration macro for the Any.

This macro calls migration macro with db value already set as sqlx::Any