OldMigrator

Trait OldMigrator 

pub trait OldMigrator<DB>: Send + Sync
where DB: Database,
{ // Required method fn applied_migrations<'life0, 'life1, 'async_trait>( &'life0 self, connection: &'life1 mut <DB as Database>::Connection, ) -> Pin<Box<dyn Future<Output = Result<Vec<Box<dyn Migration<DB>>>, Error>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait; }
Trait which is implemented for syncing a migration from old migrator to new migrator

Required Methods

fn applied_migrations<'life0, 'life1, 'async_trait>( &'life0 self, connection: &'life1 mut <DB as Database>::Connection, ) -> Pin<Box<dyn Future<Output = Result<Vec<Box<dyn Migration<DB>>>, Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Returns a list of applied migrations from the old migrator

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<DB, T> OldMigrator<DB> for T
where DB: Database, Self: DatabaseOperation<DB> + Send + Sync,