macro_rules! migration {
(
$db:ty, $op:ty, $app_name:literal, $migration_name:literal, $parents:expr, $operations:expr
) => { ... };
}Expand description
Macro for implementing the Migration trait for the provided database.
This macro will use current file name as name for migration
This macro expects the following arguments:
$db:ty: the type of database$op:ty: The type for which the migration is being implemented$app_name:literal: Name of app to be used for app variable$migration_name:literal: Name of migration to be used for thenamefunction$parents:expr: List of parents migration.$operations:expr: List of operations